@@ -2,14 +2,14 @@
 import os, sys, shutil, re, yaml
 from optparse import OptionParser
 
-import kickstart
+import kickstarter
 
 parser = OptionParser()
 parser.add_option("-t", "--template", dest="template", help="base project template", default="base")
 parser.add_option("-c", "--config", dest="config", help="yaml file to provide setup variables", default="config.yaml")
 (options, args) = parser.parse_args()
 
-template_dir = os.path.join(kickstart.__path__[0], 'templates', options.template)
+template_dir = os.path.join(kickstarter.__path__[0], 'templates', options.template)
 
 config = {}
 config['project'] = re.sub('\-', '_', args[0])
